.. :changelog:

History
=======

1.0a6 (2017-03-06)
------------------

* Improvements on imported names.
* Updated documentation and tests.

1.0a5 (2017-02-07)
------------------

* Support for methods.
* Support for instance variables.
* Support for base classes.
* Shortened the field name from "signature" to "sig".
* Use three dots instead of actual value for parameter defaults.
* Dropped support for Python 2.

1.0a4 (2017-01-06)
------------------

* Long stubs are now spread over multiple lines.
* Better handling of parameter defaults that are tuples.
* Bugfix: handling of parameter defaults that have the value None.

1.0a3 (2017-01-06)
------------------

* Proper support for names from the typing module in input parameters.
* Added parameter default values to stubs.

1.0a2 (2017-01-03)
------------------

* Support for Python 2.7.

1.0a1 (2017-01-03)
------------------

* First release on PyPI.
